@@ -1,8 +1,7 @@
-# Copyright (C) 2009 
-# Sbastien Djean, Institut de Mathematiques, Universite de Toulouse et CNRS (UMR 5219), France
-# Ignacio Gonzlez, Genopole Toulouse Midi-Pyrenees, France
-# Kim-Anh L Cao, French National Institute for Agricultural Research and 
-# ARC Centre of Excellence ins Bioinformatics, Institute for Molecular Bioscience, University of Queensland, Australia
+# Copyright (C) 2014 
+# This function was borrowed from the package caret nzv.R with some enhancements made by
+# Florian Rohart, Australian Institute for Bioengineering and Nanotechnology, University of Queensland, Brisbane, QLD.
+# Benoit Gautier, The University of Queensland, The University of Queensland Diamantina Institute, Translational Research Institute, Brisbane, QLD
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,14 +23,20 @@ function (x, freqCut = 95/5, uniqueCut = 10)
 {
     if (is.vector(x)) 
         x = matrix(x, ncol = 1)
+    
+    #speed enhancements by BG: 
     freqRatio = apply(x, 2, function(data) {
-        t = table(data[!is.na(data)])
-        if (length(t) <= 1) {
-            return(0)
-        }
-        w = which.max(t)
-        return(max(t, na.rm = TRUE)/max(t[-w], na.rm = TRUE))
+      data = na.omit(data)
+      if (length(unique(data)) == length(data)){ # No duplicate
+        return(1)
+      } else if (length(unique(data)) == 1) { # Same value
+        return(0)
+      } else {
+        t = table(data)
+        return(max(t, na.rm = TRUE)/max(t[-which.max(t)], na.rm = TRUE))
+      }
     })
+    
     lunique = apply(x, 2, function(data) length(unique(data[!is.na(data)])))
     ## changed in mixOmics, here we are dealing with matrices only
     # (FR: it might speed up computation if we have a LOT of columns
