@@ -1,7 +1,7 @@
 # Copyright (C) 2009 
-# Sébastien Déjean, Institut de Mathematiques, Universite de Toulouse et CNRS (UMR 5219), France
-# Ignacio González, Genopole Toulouse Midi-Pyrenees, France
-# Kim-Anh Lê Cao, French National Institute for Agricultural Research and 
+# Sebastien Dejean, Institut de Mathematiques, Universite de Toulouse et CNRS (UMR 5219), France
+# Ignacio Gonzalez, Genopole Toulouse Midi-Pyrenees, France
+# Kim-Anh Le Cao, French National Institute for Agricultural Research and 
 # ARC Centre of Excellence ins Bioinformatics, Institute for Molecular Bioscience, University of Queensland, Australia
 #
 # This program is free software; you can redistribute it and/or
@@ -19,21 +19,17 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
-`plot.rcc` <-
+plot.rcc <-
 function(x, scree.type = c("pointplot", "barplot"), ...) 
 {
 
-## replaced obj by 'x' to fit the generic function plot
-
-
-scree.type = match.arg(scree.type)
-if (scree.type == "pointplot") {
-plot(x$cor, xlab = "Dimension", ylim = c(0, 1),
-ylab = "Canonical correlation", ...)
+    scree.type = match.arg(scree.type)
+    if (scree.type == "pointplot") {
+        plot(x$cor, xlab = "Dimension", ylim = c(0, 1),
+        ylab = "Canonical correlation", ...)
+    }
+    else {
+        barplot(x$cor, xlab = "Dimension", ylim = c(0, 1),
+        ylab = "Canonical correlation", ...)
+    }
 }
-else {
-barplot(x$cor, xlab = "Dimension", ylim = c(0, 1),
-ylab = "Canonical correlation", ...)
-}
-}
-
